/* about.c - about window
 *
 * gSlots is a slotmachine
 *
 * 1999 Kristian Rietveld <kristian@wxs.nl>
 *
 * this program comes with ABSOLUTELY NO WARRANTY and is
 * published under the terms from the GPL
 *
 */

/* gSlots - a nice slotmachine for Linux/X-windows/GTK+
 * Copyright (C) 1999  Kristian Rietveld <kristian@wxs.nl>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include "gslots.h"

char abouttext[MAXABOUTTEXTLENGTH][128] =
{ID_STRING,
 "",
 "gSlots was written by Kristian Rietveld using the",
 "GTK+ library, see www.gtk.org for more information",
 "about GTK+.",
 "",
 "Special Thanks: Linus Torvalds and the Linux Kernel",
 "team for making Linux, the GTK+ team for developing",
 "GTK+ and the GNOME && Enlightenment developers.",
 "",
 "gSlots was inspired on the fact that there wasn't a",
 "nice slotmachine for Linux/X-windows/GNOME. So I",
 "thought, I'll write one and work on my programming",
 "experience at the same time.",
 "",
 "Thanks to:",
 "",
 "Lennert Buytenhek for learning me C, and for",
 "showing me GTK+ for the first time. I hadn't",
 "heard about GTK+ before Lennert showed me.",
 "When I had seen it, I downloaded the newest",
 "version and tutorial, and started learning it.",
 "I would also thank Lennert for showing me linux",
 "else I would still work in windoze, with a",
 "stupid dos compiler. This program wouldn't be",
 "written, if I hadn't got Linux",
 "",
 "Also thanks to the betatesters (in non-alphabetical order):",
 "",
 "Lennert Buytenhek",
 "Thijs van As",
 "Sidney Richards",
 "",
 "more...",
 "",
 "For more information/updates and patches for gslots,",
 "please visit: http://home.wxs.nl/~kristian/",
 "",
 "For bug-reports or suggestions, please mail me at:",
 "kristian@wxs.nl",
 "",
 "Copyright and other stuff",
 "",
 "gSlots - a slot machine for Linux/X-windows using GTK",
 "Copyright (C) 1999  Kristian Rietveld <kristian@wxs.nl>",
 "",
 "This program is free software; you can redistribute it and/or modify",
 "it under the terms of the GNU General Public License as published by",
 "the Free Software Foundation; either version 2 of the License, or",
 "(at your option) any later version.",
 "",
 "This program is distributed in the hope that it will be useful,",
 "but WITHOUT ANY WARRANTY; without even the implied warranty of",
 "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the",
 "GNU General Public License for more details.",
 "",
 "You should have received a copy of the GNU General Public License",
 "along with this program; if not, write to the Free Software",
 "Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.",
 ""
};

int        abouttimer;
int        abouty;
int        textheight = 0;
GdkFont   *myfont;
GtkWidget *aboutwindow;
GtkWidget *aboutmainbox;
GtkWidget *aboutwindowdraw;
GtkWidget *aboutclosebutton;
GdkPixmap *aboutpixmap;
GdkPixmap *aboutlogo;

/***** prototypes *********/
gint aboutwindow_timeout(gpointer data);
gint aboutwindowdraw_expose(GtkWidget *, GdkEventExpose *, gpointer);
gint aboutwindowdraw_configure(GtkWidget *, GdkEventConfigure *, gpointer);
void aboutwindow_destroy(GtkObject *object);
void aboutwindow_timeout_init(GtkWidget *);

/** the functions **/

gint aboutwindowdraw_configure(GtkWidget *widget, GdkEventConfigure *event,
			       gpointer data)
{
  if ( aboutpixmap)
    gdk_pixmap_unref(aboutpixmap);
  
  aboutpixmap = gdk_pixmap_new(widget->window,
			       widget->allocation.width,
			       widget->allocation.height,
			       -1);

  gdk_draw_rectangle(aboutpixmap,
		     widget->style->black_gc,
		     1,
		     0, 0,
		     ABOUTWINDOW_WIDTH,
		     ABOUTWINDOW_HEIGHT);

  return TRUE;
}

gint aboutwindowdraw_expose(GtkWidget *widget, GdkEventExpose *event,
			    gpointer data)
{
  gdk_draw_pixmap(widget->window,
		  widget->style->fg_gc[GTK_WIDGET_STATE(widget)],
		  aboutpixmap,
		  event->area.x, event->area.y,
		  event->area.x, event->area.y,
		  event->area.width, event->area.height);

  return FALSE;
}

void aboutwindow_timeout_init(GtkWidget *widget)
{
  myfont = widget->style->font;
  textheight = gdk_text_height(myfont,
			       abouttext[0],
			       strlen(abouttext[0]));
  abouty = ABOUTWINDOW_HEIGHT + textheight;

  return;
}

gint aboutwindow_timeout(gpointer data)
{
  int            t = 0;
  int            aboutx = 0;
  int            textlength = 0;
  GtkWidget     *widget;
  GdkRectangle   myrectangle;

  widget = (GtkWidget *)data;

  myrectangle.x = 0;
  myrectangle.y = 0;
  myrectangle.width = ABOUTWINDOW_WIDTH;
  myrectangle.height = ABOUTWINDOW_HEIGHT;
  
  for ( t = 0; t<MAXABOUTTEXTLENGTH;t++)
    {
      textlength = gdk_text_width(myfont,
				  abouttext[t],
				  strlen(abouttext[t]));
      
      aboutx = (ABOUTWINDOW_WIDTH - textlength) / 2;

      gdk_draw_text(aboutpixmap,
		    myfont,
		    widget->style->black_gc,
		    aboutx,
		    abouty + (t * textheight),
		    abouttext[t],
		    strlen(abouttext[t]));
    }

  if (abouty + (MAXABOUTTEXTLENGTH * textheight) - 3000 < 0)
    {
      gdk_draw_rectangle(aboutpixmap,
			 widget->style->black_gc,
			 TRUE,
			 150, abouty + (MAXABOUTTEXTLENGTH * textheight),
			 200, 120);
    }
  
  if (abouty + (MAXABOUTTEXTLENGTH * textheight) + 100 < 0)
    abouty = ABOUTWINDOW_HEIGHT + textheight;
  else
    abouty -= 2;
  
  for ( t = 0; t<MAXABOUTTEXTLENGTH;t++)
    {
      textlength = gdk_text_width(myfont,
				  abouttext[t],
				  strlen(abouttext[t]));
      
      aboutx = (ABOUTWINDOW_WIDTH - textlength) / 2;
     
      gdk_draw_text(aboutpixmap,
		    myfont,
		    widget->style->white_gc,
		    aboutx, 
		    abouty + (t * textheight),
		    abouttext[t],
		    strlen(abouttext[t]));
    }
  
  if (abouty + (MAXABOUTTEXTLENGTH * textheight) - 300 < 0)
    {
      gdk_draw_pixmap(aboutpixmap,
		      widget->style->white_gc,
		      aboutlogo,
		      0, 0,
		      150, abouty + (MAXABOUTTEXTLENGTH * textheight),
		      200, 120);
    }

  gtk_widget_draw(widget, &myrectangle);
  
  return TRUE;
}

void aboutwindow_destroy(GtkObject *object)
{
  gtk_timeout_remove(abouttimer);
  gtk_widget_destroy(GTK_WIDGET(object));
}

void display_about_window()
{
  GtkStyle  *tmpstyle;
  GdkBitmap *tmpmask;
 
  aboutwindow = gtk_window_new(GTK_WINDOW_TOPLEVEL);
  gtk_window_set_policy(GTK_WINDOW(aboutwindow),
			FALSE, FALSE, FALSE);
  gtk_window_set_title(GTK_WINDOW(aboutwindow),
		       ID "- About window");
  gtk_signal_connect_object(GTK_OBJECT(aboutwindow),
			    "destroy",
			    GTK_SIGNAL_FUNC(aboutwindow_destroy),
			    GTK_OBJECT(aboutwindow));
  gtk_signal_connect_object(GTK_OBJECT(aboutwindow),
			    "delete_event",
			    GTK_SIGNAL_FUNC(aboutwindow_destroy),
			    GTK_OBJECT(aboutwindow));
  gtk_container_border_width(GTK_CONTAINER(aboutwindow), 5);

  aboutmainbox = gtk_vbox_new(FALSE, 2);
  gtk_container_add(GTK_CONTAINER(aboutwindow), aboutmainbox);
  gtk_widget_show(aboutmainbox);

  aboutwindowdraw = gtk_drawing_area_new();
  gtk_drawing_area_size(GTK_DRAWING_AREA(aboutwindowdraw),
			ABOUTWINDOW_WIDTH,
			ABOUTWINDOW_HEIGHT);
  gtk_signal_connect(GTK_OBJECT(aboutwindowdraw), "configure_event",
		     GTK_SIGNAL_FUNC(aboutwindowdraw_configure),
		     NULL);
  gtk_signal_connect(GTK_OBJECT(aboutwindowdraw), "expose_event",
		     GTK_SIGNAL_FUNC(aboutwindowdraw_expose),
		     NULL);
  gtk_widget_set_events(aboutwindowdraw, GDK_EXPOSURE_MASK);
  gtk_widget_set_usize(aboutwindowdraw, ABOUTWINDOW_WIDTH,
		       ABOUTWINDOW_HEIGHT);
  gtk_box_pack_start(GTK_BOX(aboutmainbox), aboutwindowdraw,
		     FALSE, FALSE, 2);
  gtk_widget_show(aboutwindowdraw);

  aboutclosebutton = gtk_button_new_with_label("Close About Window");
  gtk_signal_connect_object(GTK_OBJECT(aboutclosebutton), "clicked",
			    GTK_SIGNAL_FUNC(aboutwindow_destroy),
			    GTK_OBJECT(aboutwindow));
  gtk_box_pack_start(GTK_BOX(aboutmainbox), aboutclosebutton,
		     TRUE, TRUE, 2);
  gtk_widget_show(aboutclosebutton);

  aboutwindow_timeout_init(aboutwindowdraw);
  abouttimer = gtk_timeout_add(75, aboutwindow_timeout,
			       (gpointer)aboutwindowdraw);

  gtk_widget_show(aboutwindow);

  /*** load aboutlogo pixmap ***/

  tmpstyle = gtk_widget_get_style(aboutwindow);
  aboutlogo = gdk_pixmap_create_from_xpm(aboutwindow->window,
					 &tmpmask, 
					 &tmpstyle->bg[GTK_STATE_NORMAL],
					 "/usr/share/gslots/about.xpm");

  return;
}


