/* gslots.c - main file
 *
 * gSlots is a slotmachine
 *
 * 1999 Kristian Rietveld <kristian@wxs.nl>
 *
 * this program comes with ABSOLUTELY NO WARRANTY and is published under the
 * terms from the GPL
 *
 */

/* gSlots - a nice slotmachine for Linux/X-windows/GTK+
 * Copyright (C) 1999  Kristian Rietveld <kristian@wxs.nl>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include "gslots.h"

/*** important variables ***/

int                 slotspix[3][MAX_PIX_AT_SLOT];
int                 numberofscores;
int                 numberofslotspix[3];
GtkWidget          *window;
GtkWidget          *progbar;
GtkWidget          *label;
GdkPixmap          *thelogo = NULL;
GdkPixmap          *thepixmap = NULL;
GdkPixmap          *pixmaps[MAX_PIXMAPS];
GdkPixmap          *s_pixmaps[MAX_PIXMAPS];
GdkPixmap          *digits[12]; /* 0 t/m 9 && '.' && ' ' */
struct gamewindow   gw;
struct scoreentry   thescores[MAX_SCORES];

/************* some game values ******************/
gfloat credits = 200.00;
gfloat wager = 0.00;
gfloat won = 0.00;

/*** prototypes ***/
gint logo_draw_expose(GtkWidget *, GdkEventExpose *);
gint logo_draw_configure(GtkWidget *, GdkEventConfigure *);
void splash();

/** the functions **/

int main(int argc, char *argv[])
{
  gtk_init(&argc, &argv);

  splash();

  return 0;
}

void splash()
{
  int        thetimer;

  GtkWidget *draw;
  GtkWidget *box;

  window = gtk_window_new(GTK_WINDOW_POPUP);
  gtk_window_set_title(GTK_WINDOW(window), "gSlots v0.0");
  gtk_window_set_policy(GTK_WINDOW(window), FALSE, FALSE, FALSE);
  gtk_window_position(GTK_WINDOW(window), GTK_WIN_POS_CENTER);
  gtk_container_border_width(GTK_CONTAINER(window), 10);

  box = gtk_vbox_new(FALSE, 0);
  gtk_container_add(GTK_CONTAINER(window), box);

  draw = gtk_drawing_area_new();
  gtk_drawing_area_size(GTK_DRAWING_AREA(draw), 320, 240);
  gtk_widget_set_usize(draw, 320, 240);
  gtk_signal_connect(GTK_OBJECT(draw), "configure_event",
		     GTK_SIGNAL_FUNC(logo_draw_configure), NULL);
  gtk_signal_connect(GTK_OBJECT(draw), "expose_event",
		     GTK_SIGNAL_FUNC(logo_draw_expose), NULL);
  gtk_widget_set_events(draw, GDK_EXPOSURE_MASK);
  gtk_box_pack_start(GTK_BOX(box), draw, FALSE, FALSE, 0);
  gtk_widget_show(draw);

  label = gtk_label_new("Loading...");
  gtk_box_pack_start(GTK_BOX(box), label, TRUE, TRUE, 2);
  gtk_widget_show(label);

  progbar = gtk_progress_bar_new();
  gtk_widget_set_usize(GTK_WIDGET(progbar), 318, 10);
  gtk_box_pack_start(GTK_BOX(box), progbar, TRUE, TRUE, 2);
  gtk_widget_show(progbar);

  thetimer = gtk_timeout_add(50, progress_timeout, progbar);

  gtk_widget_show(box);
  gtk_widget_show(window);

  gtk_main();
}

gint logo_draw_configure(GtkWidget *widget, GdkEventConfigure *event)
{
  GtkStyle   *style;
  GdkBitmap  *mask;

  if (thepixmap)
    gdk_pixmap_unref(thepixmap);

  thepixmap = gdk_pixmap_new(widget->window,
			     widget->allocation.width,
			     widget->allocation.height,
			     -1);
    
  style = gtk_widget_get_style(widget);
  thelogo = gdk_pixmap_create_from_xpm(widget->window,
				       &mask, &style->bg[GTK_STATE_NORMAL],
				       "/usr/share/gslots/gslots.xpm");
  gdk_draw_pixmap(thepixmap,
		  widget->style->bg_gc[GTK_WIDGET_STATE(widget)],
		  thelogo,
		  0, 0,
		  0, 0,
		  320, 240);				     
  
  return TRUE;
}

gint logo_draw_expose(GtkWidget *widget, GdkEventExpose *event)
{
  gdk_draw_pixmap(widget->window,
		  widget->style->fg_gc[GTK_WIDGET_STATE(widget)],
		  thepixmap,
		  event->area.x, event->area.y,
		  event->area.x, event->area.y,
		  event->area.width, event->area.height);
  
  return FALSE;
}

void message(const char *text)
{
  /***** builds a dialog with one button with
	 text in it **************************/

  GtkWidget *dialogwindow;
  GtkWidget *dialogwindowbox;
  GtkWidget *dialoglabel;
  GtkWidget *dialogseparator;
  GtkWidget *dialogokbutton;

  dialogwindow = gtk_window_new(GTK_WINDOW_DIALOG);
  gtk_signal_connect_object(GTK_OBJECT(dialogwindow), "destroy",
			    GTK_SIGNAL_FUNC(gtk_widget_destroy),
			    GTK_OBJECT(dialogwindow));
  gtk_signal_connect_object(GTK_OBJECT(dialogwindow), "delete_event",
			    GTK_SIGNAL_FUNC(gtk_widget_destroy),
			    GTK_OBJECT(dialogwindow));
  gtk_window_set_title(GTK_WINDOW(dialogwindow),
		       "Message");
  gtk_window_set_policy(GTK_WINDOW(dialogwindow),
			FALSE, FALSE, FALSE);
  gtk_container_border_width(GTK_CONTAINER(dialogwindow),
			     5);
  
  dialogwindowbox = gtk_vbox_new(FALSE, 5);
  gtk_container_add(GTK_CONTAINER(dialogwindow), dialogwindowbox);
  gtk_widget_show(dialogwindowbox);

  dialoglabel = gtk_label_new(text);
  gtk_box_pack_start(GTK_BOX(dialogwindowbox),
		     dialoglabel, FALSE, FALSE, 0);
  gtk_widget_show(dialoglabel);

  dialogseparator = gtk_hseparator_new();
  gtk_box_pack_start(GTK_BOX(dialogwindowbox),
		     dialogseparator, FALSE, FALSE, 0);
  gtk_widget_show(dialogseparator);

  dialogokbutton = gtk_button_new_with_label("OK");
  gtk_signal_connect_object(GTK_OBJECT(dialogokbutton),
			    "clicked",
			    GTK_SIGNAL_FUNC(gtk_widget_destroy),
			    GTK_OBJECT(dialogwindow));
  gtk_box_pack_start(GTK_BOX(dialogwindowbox),
		     dialogokbutton, FALSE, FALSE, 0);
  gtk_widget_show(dialogokbutton);
  
  gtk_widget_show(dialogwindow);
}
