/* init.c - gSlots init (reading pixmaps/building window)
 *
 * gSlots is a slotmachine
 *
 * 1999 Kristian Rietveld <kristian@wxs.nl>
 *
 * this program comes with ABSOLUTELY NO WARRANTY and is published under the
 * terms from the GPL
 *
 */

/* gSlots - a nice slotmachine for Linux/X-windows/GTK+
 * Copyright (C) 1999  Kristian Rietveld <kristian@wxs.nl>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include "gslots.h"

/** externs **/

extern int                slotspix[3][MAX_PIX_AT_SLOT];
extern int                numberofscores;
extern int                numberofslotspix[3];
extern int                payoffwindowopened;
extern gfloat             won;
extern gfloat             wager;
extern gfloat             credits;
extern GtkWidget         *payoffwindow;
extern GdkPixmap         *digits[12]; /* 0 t/m 9 && '.' && ' ' */
extern GdkPixmap         *pixmaps[MAX_PIXMAPS];
extern GdkPixmap         *s_pixmaps[MAX_PIXMAPS];
extern struct gamewindow  gw;
extern struct scoreentry  thescores[MAX_SCORES];

/** important stuff **/

int        initbuildslots = 0;
int        initwindowbuilt = 0;
int        initdigitloaded = 0;
int        initpixmapsloaded = 0;
GtkWidget *label;
GtkWidget *window;
GtkWidget *progbar;

/** prototypes **/

int digit_load(int);
int pixmap_load(const char *, int);
int parse_slotsinit_line(int *myarray, const char *buffer);
gint slot_draw_expose(GtkWidget *, GdkEventExpose *, gint);
gint score_draw_expose(GtkWidget *, GdkEventExpose *, gint);
gint slow_draw_configure(GtkWidget *, GdkEventConfigure *, gint);
gint score_draw_configure(GtkWidget *, GdkEventConfigure *, gint);
void init_slots();
void init_values();
void init_random_seed();
void parse_scores_file();
void draw_digit_on_score(int, int, int);

/** functions **/

gint slot_draw_configure(GtkWidget *widget, GdkEventConfigure *event, gint slotnum)
{
  if (gw.slot[slotnum])
    gdk_pixmap_unref(gw.slot[slotnum]);

  gw.slot[slotnum] = gdk_pixmap_new(widget->window,
				    90, 330, -1);

  gdk_draw_rectangle(gw.slot[slotnum],
		     widget->style->white_gc,
		     1,
		     0, 0,
		     90, 330);
  
  return TRUE;
}

gint score_draw_configure(GtkWidget *widget, GdkEventConfigure *event, gint scorenum)
{
  int         t = 0;

  if (gw.scoremaps[scorenum])
    gdk_pixmap_unref(gw.scoremaps[scorenum]);

  gw.scoremaps[scorenum] = gdk_pixmap_new(widget->window,
					 128, 32, -1);
  for(t = 0; t < 9 ; t++)
    {
      if (t == 5)
	{
	  gdk_draw_pixmap(gw.scoremaps[scorenum],
			  widget->style->black_gc,
			  digits[10],
			  0, 0,
			  t * 16, 0,
			  16, 32);
	}
      else
	{
	  gdk_draw_pixmap(gw.scoremaps[scorenum],
			  widget->style->black_gc,
			  digits[11],
			  0, 0,
			  t * 16, 0,
			  16, 32);
	}
    }

  return TRUE;
}

gint score_draw_expose(GtkWidget *widget, GdkEventExpose *event, gint scorenum)
{
  gdk_draw_pixmap(widget->window,
		  widget->style->black_gc,
		  gw.scoremaps[scorenum],
		  event->area.x - 1, event->area.y - 1,
		  event->area.x, event->area.y,
		  event->area.width, event->area.height);
  
  gtk_draw_shadow(widget->style,
		  widget->window,
		  GTK_WIDGET_STATE(widget),
		  GTK_SHADOW_IN,
		  0, 0, 130, 34);

  return FALSE;
}

gint slot_draw_expose(GtkWidget *widget, GdkEventExpose *event, gint slotnum)
{
  gdk_draw_pixmap(widget->window,
		  widget->style->fg_gc[GTK_WIDGET_STATE(widget)],
		  gw.slot[slotnum],
		  event->area.x - 1, event->area.y - 1,
		  event->area.x, event->area.y,
		  event->area.width, event->area.height);

  gtk_draw_shadow(widget->style,
		  widget->window,
		  GTK_WIDGET_STATE(widget),
		  GTK_SHADOW_IN,
		  0, 0, 92, 332);

  return FALSE;
}

void update_score_display(gint scorenum, gfloat score)
{
  int          t = 0;
  int          num[9];
  int          temp = 0;
  char         scorestring[9];
  GdkRectangle update_rect;

  update_rect.x = 0;
  update_rect.y = 0;
  update_rect.width = 128;
  update_rect.height = 32;

  sprintf(scorestring, "%08.2f", (float)score);
  scorestring[strlen(scorestring)] = 0;
 
  for(t=0;t<8;t++)
    num[t] = scorestring[t] - 48;
   
  for(t=0;t<8;t++)
    {
      if ( num[t] == 0 && temp == 1)
	draw_digit_on_score(num[t], t, (int)scorenum);

      if ( num[t] == 0 && temp == 0)
	draw_digit_on_score(11, t, (int)scorenum);

      if ( num[t] > 0 && num[t] < 10)
	{
	  temp = 1;
	  draw_digit_on_score(num[t], t, (int)scorenum);
	}

      if ( t == 4 && num[t] == 0 && temp == 0)
	{
	  temp = 1;
	  draw_digit_on_score(0, t, (int)scorenum);
	}

      if ( t == 5 )
	{
	  temp = 1;
	  draw_digit_on_score(10, t, (int)scorenum);
	}
    }

  gtk_widget_draw(gw.scoredraw[scorenum], &update_rect);
}

void draw_digit_on_score(int thedigit, int place, int scorenum)
{
  if ( thedigit > -1 && thedigit < 12)
    gdk_draw_pixmap(gw.scoremaps[scorenum],
		    gw.window->style->black_gc,
		    digits[thedigit],
		    0, 0,
		    place * 16, 0,
		    16, 32);
}

void gamewindow_close(GtkWidget *widget, gpointer data)
{
  if ( payoffwindowopened)
    payoff_window_close((GtkWidget *)gw.window, (gpointer)payoffwindow);
  gtk_main_quit();
}

gint progress_timeout(gpointer data)
{
  int        t = 0;
  int        pixmaptempint = 0;
  int        pixmapsinitfileread = 0;
  char       buffer[128];
  char       templabel[64];
  char       temppixmapname[64];
  FILE      *pixmapsinitfile;
  gfloat     value;
  GtkStyle  *style;
  GdkBitmap *mask;

  value = gtk_progress_get_value(GTK_PROGRESS(data));

  value += 2;
  gtk_progress_set_value(GTK_PROGRESS(data), value);

  /******************** init: load pixmaps **********************/

  if ( initpixmapsloaded == 0)
    {
      sprintf(templabel, "Loading: pixmaps\n");
      gtk_label_set_text(GTK_LABEL(label), templabel);
      
      if ( (pixmapsinitfile = fopen("/usr/share/gslots/pixmaps", "r")) == NULL)
	{
	  perror("gslots: can't read pixmaps file");

	  gtk_widget_destroy(window);
	  return (FALSE);
	}

      while(!pixmapsinitfileread)
	{
	  if ( fgets(buffer, 127, pixmapsinitfile) == NULL)
	    {
	      pixmapsinitfileread = 1;
	      break;
	    }
	  
	  if ( buffer[0] == '#' )
	    continue;
	  
	  sscanf(buffer, "%d %s\n",
		 &pixmaptempint,
		 temppixmapname);
	  
	  if ( pixmaptempint > MAX_PIXMAPS)
	    continue;
	  
	  if (pixmap_load(temppixmapname, pixmaptempint) < 0)
	    {
	      fclose(pixmapsinitfile);
	      gtk_widget_destroy(window);
	      printf("gslots: failed loading pixmaps (%s, %d)\n",
		     temppixmapname, pixmaptempint);
	      return (FALSE);
	    }

	  value += 2;
	  gtk_progress_set_value(GTK_PROGRESS(data), value);
	  
	}
      
      fclose(pixmapsinitfile);

      initpixmapsloaded = 1;
      
      sprintf(templabel, "Loading...\n");
      gtk_label_set_text(GTK_LABEL(label), templabel);
    }

  /******************* init: done loading pixmaps ********************/
  /******************* init: loading digit pixmaps ******************/

  if ( initdigitloaded == 0)
    {
      sprintf(templabel, "Loading: pixmaps...\n");
      gtk_label_set_text(GTK_LABEL(label), templabel);

      for(t=0;t<10;t++)
	{
	  if ( digit_load(t) < 0)
	    {
	      gtk_widget_destroy(window);
	      printf("gslots: failed loading pixmaps\n");
	      return (FALSE);
	    }

	  value += 2;
	  gtk_progress_set_value(GTK_PROGRESS(data), value);
	}
            
      style = gtk_widget_get_style(window);
      digits[10] = gdk_pixmap_create_from_xpm(window->window,
					      &mask, &style->black,
					      "/usr/share/gslots/pix/digitd.xpm");

      digits[11] = gdk_pixmap_create_from_xpm(window->window,
					      &mask, &style->black,
					      "/usr/share/gslots/pix/digit.xpm");

      sprintf(templabel, "Loading...\n");
      gtk_label_set_text(GTK_LABEL(label), templabel);

      initdigitloaded = 1;
    }
  /******************* init: done loading digit pixmaps **************/

  /******************* init: building game window *******************/

  if (initwindowbuilt == 0)
    {
      sprintf(templabel, "Loading: building game window\n");
      gtk_label_set_text(GTK_LABEL(label), templabel);
      
      gw.window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
      gtk_window_set_title(GTK_WINDOW(gw.window), ID);
      gtk_window_set_policy(GTK_WINDOW(gw.window), FALSE, FALSE, FALSE);
      gtk_signal_connect(GTK_OBJECT(gw.window), "delete_event",
			 GTK_SIGNAL_FUNC(gamewindow_close), NULL);
      gtk_signal_connect(GTK_OBJECT(gw.window), "destroy",
			 GTK_SIGNAL_FUNC(gamewindow_close), NULL);
      gtk_container_border_width(GTK_CONTAINER(gw.window), 3);
      
      value += 2;
      gtk_progress_set_value(GTK_PROGRESS(data), value);

      gw.mainbox = gtk_vbox_new(FALSE, 5);
      gtk_container_add(GTK_CONTAINER(gw.window), gw.mainbox);
      gtk_widget_show(gw.mainbox);

      value += 2;
      gtk_progress_set_value(GTK_PROGRESS(data), value);

      gw.gamefield = gtk_hbox_new(FALSE, 10);
      gtk_box_pack_start(GTK_BOX(gw.mainbox), gw.gamefield, FALSE, FALSE, 3);
      gtk_widget_show(gw.gamefield);      

      value += 2;
      gtk_progress_set_value(GTK_PROGRESS(data), value);

      gw.leftbox = gtk_vbox_new(FALSE, 10);
      gtk_box_pack_start(GTK_BOX(gw.gamefield), gw.leftbox, FALSE, FALSE, 3);
      gtk_widget_show(gw.leftbox);

      value += 2;
      gtk_progress_set_value(GTK_PROGRESS(data), value);

      gw.holdbox = gtk_hbox_new(TRUE, 35);
      gtk_box_pack_start(GTK_BOX(gw.leftbox), gw.holdbox, FALSE, FALSE, 3);
      gtk_widget_show(gw.holdbox);

      value += 2;
      gtk_progress_set_value(GTK_PROGRESS(data), value);

      for(t=0;t<3;t++)
	{
	  gw.holdbuttons[t] = gtk_toggle_button_new_with_label("Hold");
	  gtk_widget_set_usize(GTK_WIDGET(gw.holdbuttons[t]), 94, 20);
	  gtk_box_pack_start(GTK_BOX(gw.holdbox), gw.holdbuttons[t], 
			     TRUE, TRUE, 0);
	  gtk_widget_show(gw.holdbuttons[t]);

	  value += 2;
	  gtk_progress_set_value(GTK_PROGRESS(data), value);
	}
      
      value += 2;
      gtk_progress_set_value(GTK_PROGRESS(data), value);

      gw.holdseparator = gtk_hseparator_new();
      gtk_box_pack_start(GTK_BOX(gw.leftbox), gw.holdseparator,
			 FALSE, FALSE, 3);
      gtk_widget_show(gw.holdseparator);

      value += 2;
      gtk_progress_set_value(GTK_PROGRESS(data), value);

      gw.slotbox = gtk_hbox_new(TRUE, 35);
      gtk_box_pack_start(GTK_BOX(gw.leftbox), gw.slotbox, FALSE, FALSE, 3);
      gtk_widget_show(gw.slotbox);

      value += 2;
      gtk_progress_set_value(GTK_PROGRESS(data), value);

      for(t=0;t<3;t++)
	{
	  gw.slotdraw[t] = gtk_drawing_area_new();
	  gtk_drawing_area_size(GTK_DRAWING_AREA(gw.slotdraw[t]), 94, 334);
	  gtk_signal_connect(GTK_OBJECT(gw.slotdraw[t]), "configure_event",
			     GTK_SIGNAL_FUNC(slot_draw_configure), (gpointer)t);
	  gtk_signal_connect(GTK_OBJECT(gw.slotdraw[t]), "expose_event",
			     GTK_SIGNAL_FUNC(slot_draw_expose), (gpointer)t);
	  gtk_widget_set_events(gw.slotdraw[t], GDK_EXPOSURE_MASK);
	  gtk_box_pack_start(GTK_BOX(gw.slotbox), gw.slotdraw[t], TRUE, TRUE, 0);
	  gtk_widget_show(gw.slotdraw[t]);
	
	  value += 2;
	  gtk_progress_set_value(GTK_PROGRESS(data), value);
	}

      value += 2;
      gtk_progress_set_value(GTK_PROGRESS(data), value);

      gw.vsep = gtk_vseparator_new();
      gtk_box_pack_start(GTK_BOX(gw.gamefield), gw.vsep, FALSE, FALSE, 3);
      gtk_widget_show(gw.vsep);
      
      value += 2;
      gtk_progress_set_value(GTK_PROGRESS(data), value);

      gw.scorebox = gtk_vbox_new(FALSE, 10);
      gtk_box_pack_start(GTK_BOX(gw.gamefield), gw.scorebox, FALSE, FALSE, 3);
      gtk_widget_show(gw.scorebox);

      value += 2;
      gtk_progress_set_value(GTK_PROGRESS(data), value);

      gw.creditlabel = gtk_label_new("Credits:");
      gtk_box_pack_start(GTK_BOX(gw.scorebox), gw.creditlabel, FALSE, FALSE, 0);
      gtk_widget_show(gw.creditlabel);

      gw.scoredraw[0] = gtk_drawing_area_new();
      gtk_drawing_area_size(GTK_DRAWING_AREA(gw.scoredraw[0]), 132, 36);
      gtk_signal_connect(GTK_OBJECT(gw.scoredraw[0]), "configure_event",
			 GTK_SIGNAL_FUNC(score_draw_configure), (gpointer)0);
      gtk_signal_connect(GTK_OBJECT(gw.scoredraw[0]), "expose_event",
			 GTK_SIGNAL_FUNC(score_draw_expose), (gpointer)0);
      gtk_widget_set_events(gw.scoredraw[0], GDK_EXPOSURE_MASK);
      gtk_box_pack_start(GTK_BOX(gw.scorebox), gw.scoredraw[0], FALSE, FALSE, 0);
      gtk_widget_show(gw.scoredraw[0]);
      
      gw.wagerlabel = gtk_label_new("Wager:");
      gtk_box_pack_start(GTK_BOX(gw.scorebox), gw.wagerlabel, FALSE, FALSE, 0);
      gtk_widget_show(gw.wagerlabel);

      gw.scoredraw[1] = gtk_drawing_area_new();
      gtk_drawing_area_size(GTK_DRAWING_AREA(gw.scoredraw[1]), 132, 36);
      gtk_signal_connect(GTK_OBJECT(gw.scoredraw[1]), "configure_event",
			 GTK_SIGNAL_FUNC(score_draw_configure), (gpointer)1);
      gtk_signal_connect(GTK_OBJECT(gw.scoredraw[1]), "expose_event",
			 GTK_SIGNAL_FUNC(score_draw_expose), (gpointer)1);
      gtk_widget_set_events(gw.scoredraw[1], GDK_EXPOSURE_MASK);
      gtk_box_pack_start(GTK_BOX(gw.scorebox), gw.scoredraw[1], FALSE, FALSE, 0);
      gtk_widget_show(gw.scoredraw[1]);

      gw.wonlabel = gtk_label_new("Won:");
      gtk_box_pack_start(GTK_BOX(gw.scorebox), gw.wonlabel, FALSE, FALSE, 0);
      gtk_widget_show(gw.wonlabel);

      gw.scoredraw[2] = gtk_drawing_area_new();
      gtk_drawing_area_size(GTK_DRAWING_AREA(gw.scoredraw[2]), 132, 36);
      gtk_signal_connect(GTK_OBJECT(gw.scoredraw[2]), "configure_event",
			 GTK_SIGNAL_FUNC(score_draw_configure), (gpointer)2);
      gtk_signal_connect(GTK_OBJECT(gw.scoredraw[2]), "expose_event",
			 GTK_SIGNAL_FUNC(score_draw_expose), (gpointer)2);
      gtk_widget_set_events(gw.scoredraw[2], GDK_EXPOSURE_MASK);
      gtk_box_pack_start(GTK_BOX(gw.scorebox), gw.scoredraw[2], FALSE, FALSE, 0);
      gtk_widget_show(gw.scoredraw[2]);

      value += 2;
      gtk_progress_set_value(GTK_PROGRESS(data), value);

      gw.hsep = gtk_hseparator_new();
      gtk_box_pack_start(GTK_BOX(gw.mainbox), gw.hsep, FALSE, FALSE, 3);
      gtk_widget_show(gw.hsep);

      value += 2;
      gtk_progress_set_value(GTK_PROGRESS(data), value);
      
      gw.buttonbox = gtk_hbox_new(TRUE, 5);
      gtk_box_pack_start(GTK_BOX(gw.mainbox), gw.buttonbox, FALSE, FALSE, 3);
      gtk_widget_show(gw.buttonbox);

      value += 2;
      gtk_progress_set_value(GTK_PROGRESS(data), value);

      gw.quitbutton = gtk_button_new_with_label("Quit");
      gtk_signal_connect(GTK_OBJECT(gw.quitbutton), "clicked",
			 GTK_SIGNAL_FUNC(quit_gslots), NULL);
      gtk_signal_connect(GTK_OBJECT(gw.quitbutton), "clicked",
			 GTK_SIGNAL_FUNC(gamewindow_close), NULL);
      gtk_widget_set_usize(GTK_WIDGET(gw.quitbutton), 0, 40);
      gtk_box_pack_start(GTK_BOX(gw.buttonbox), gw.quitbutton, TRUE, TRUE, 0);
      gtk_widget_show(gw.quitbutton);

      value += 2;
      gtk_progress_set_value(GTK_PROGRESS(data), value);
      
      gw.aboutbutton = gtk_button_new_with_label("About");
      gtk_signal_connect(GTK_OBJECT(gw.aboutbutton), "clicked",
			 GTK_SIGNAL_FUNC(display_about_window),
			 NULL);
      gtk_widget_set_usize(GTK_WIDGET(gw.aboutbutton), 0, 40);
      gtk_box_pack_start(GTK_BOX(gw.buttonbox), 
			 gw.aboutbutton, TRUE, TRUE, 0);
      gtk_widget_show(gw.aboutbutton);

      value += 2;
      gtk_progress_set_value(GTK_PROGRESS(data), value);

      gw.payoffchartbutton = gtk_button_new_with_label("Payoff Chart");
      gtk_signal_connect(GTK_OBJECT(gw.payoffchartbutton), "clicked",
			 GTK_SIGNAL_FUNC(display_payoffchart), NULL);
      gtk_widget_set_usize(GTK_WIDGET(gw.payoffchartbutton), 0, 40);
      gtk_box_pack_start(GTK_BOX(gw.buttonbox), 
			 gw.payoffchartbutton, TRUE, TRUE, 0);
      gtk_widget_show(gw.payoffchartbutton);

      value += 2;
      gtk_progress_set_value(GTK_PROGRESS(data), value);
      
      gw.betmorebutton = gtk_button_new_with_label("Bet more");
      gtk_signal_connect(GTK_OBJECT(gw.betmorebutton), "clicked",
			 GTK_SIGNAL_FUNC(bet_1_more_buck), NULL);
      gtk_widget_set_usize(GTK_WIDGET(gw.betmorebutton), 0, 40);
      gtk_box_pack_start(GTK_BOX(gw.buttonbox), 
			 gw.betmorebutton, TRUE, TRUE, 0);
      gtk_widget_show(gw.betmorebutton);

      value += 2;
      gtk_progress_set_value(GTK_PROGRESS(data), value);
      
      gw.betmaxbutton = gtk_button_new_with_label("Bet max");
      gtk_signal_connect(GTK_OBJECT(gw.betmaxbutton), "clicked",
			 GTK_SIGNAL_FUNC(bet_max_bucks), NULL);
      gtk_widget_set_usize(GTK_WIDGET(gw.betmaxbutton), 0, 40);
      gtk_box_pack_start(GTK_BOX(gw.buttonbox), 
			 gw.betmaxbutton, TRUE, TRUE, 0);
      gtk_widget_show(gw.betmaxbutton);

      value += 2;
      gtk_progress_set_value(GTK_PROGRESS(data), value);

      gw.spinbutton = gtk_button_new_with_label("Spin!");
      gtk_signal_connect(GTK_OBJECT(gw.spinbutton), "clicked", 
			 GTK_SIGNAL_FUNC(spin_slots), NULL);
      gtk_widget_set_usize(GTK_WIDGET(gw.spinbutton), 0, 40);
      gtk_box_pack_start(GTK_BOX(gw.buttonbox), gw.spinbutton, TRUE, TRUE, 0);
      gtk_widget_show(gw.spinbutton);
      
      value += 2;
      gtk_progress_set_value(GTK_PROGRESS(data), value);
    
      gw.statusbar = gtk_statusbar_new();
      gtk_box_pack_start(GTK_BOX(gw.mainbox), gw.statusbar,
			 FALSE, FALSE, 0);
      gtk_widget_show(gw.statusbar);
      gw.context_id = gtk_statusbar_get_context_id(GTK_STATUSBAR(gw.statusbar),
						   "gSlots Statusbar");
      gtk_statusbar_push(GTK_STATUSBAR(gw.statusbar), gw.context_id,
			 "Welcome to "ID);

      sprintf(templabel, "Loading...\n");
      gtk_label_set_text(GTK_LABEL(label), templabel);

      initwindowbuilt = 1;
    }

  /******************** init: done building game window *************/

  if (value < 100)
    return (TRUE);
  else
    {
      gtk_widget_hide(window);
      gtk_widget_destroy(window);
      gtk_widget_show(gw.window);
      init_random_seed();
      init_slots();
      init_values();
      parse_scores_file();
      return(FALSE);
    }
}

void init_random_seed()
{
  int   number[2];
  FILE *randomdevice;
#ifndef __hpux
  if ( (randomdevice = fopen("/dev/random", "r")) == NULL)
    {
      perror("error");
      printf("error: can't open /dev/random to initialize random"
	       " seed generator\n");
      srand(234);
      return;
    }

  
  number[0] = fgetc(randomdevice);
  number[1] = fgetc(randomdevice);

  srand((number[0] * number[1]));

  fclose(randomdevice);
#else
      srand(234); /*  Thats all you get on HPUX :) */
#endif
  return;
}

void init_values()
{
  won     =   0.00;
  wager   =   0.25;
  credits = 200.00;

  update_score_display(0, credits);
  update_score_display(1, wager);
  update_score_display(2, won);
}

void parse_scores_file()
{
  int   t = 0;
  int   scoresinitfileread = 0;
  char  buffer[128];
  FILE *scoresinit;

  if ( (scoresinit = fopen("/usr/share/gslots/scores", "r")) == NULL)
    {
      perror("gslots: can't open scores");
      return;
    }

  while(!scoresinitfileread)
    {
      if ( fgets(buffer, 127, scoresinit) == NULL)
	{
	  scoresinitfileread = 1;
	  break;
	}

      if ( buffer[0] == '#' )
	continue;
      
     sscanf(buffer, "%d %d %d %d\n",
	    &thescores[t].picatslot[0], &thescores[t].picatslot[1],
	    &thescores[t].picatslot[2], &thescores[t].score);
     t++;
    }

  numberofscores = t;

  fclose(scoresinit);
}

void init_slots()
{
  int   t = 0;
  int   tt = 0;
  int   slotsinitfileread = 0;
  char  buffer[128];
  FILE *slotsinit;

  if ( (slotsinit = fopen("/usr/share/gslots/slots", "r")) == NULL)
    {
      perror("init.c: error opening slots file");

      return;
    }

  t = 0;
  
  while(!slotsinitfileread)
    {
      if ( fgets(buffer, 127, slotsinit) == NULL)
	{
	  slotsinitfileread = 1;
	  break;
	}

      if ( buffer[0] == '#' )
	continue;
      
      if ( buffer[0] == ' ' )
	continue;
      
      if ( (numberofslotspix[t] = 
	    parse_slotsinit_line((int *)slotspix[t], 
				 (const char *)buffer)) < 0)
	{
	  fclose(slotsinit);
	  return;
	}
      else
	t++;
    }

  fclose(slotsinit);

  t = 0;

  for (t = 0; t < 3; t++)
    {
      GdkRectangle update_rect;
      
      update_rect.x = 0;
      update_rect.y = 0;
      update_rect.width = 90;
      update_rect.height = 330;
      
      gw.theslot[t] = gdk_pixmap_new(gw.window->window,
				     90, MAX_PIX_AT_SLOT*110, -1);
                 
      for ( tt = 0; tt < numberofslotspix[t]; tt++)
	{
	  gdk_draw_pixmap(gw.theslot[t],
			  gw.slotdraw[t]->style->black_gc,
			  pixmaps[slotspix[t][tt]],
			  0, 0,
			  0, 110*tt,
			  90, 110);
	}

      gdk_draw_pixmap(gw.slot[t], 
		      gw.slotdraw[t]->style->black_gc,
		      gw.theslot[t],
		      0, 0,
		      0, 0,
		      90, 330);
      
      gw.slotrotate[t] = 0;
      gtk_widget_draw(gw.slotdraw[t], &update_rect);
    }

  return;
}

int parse_slotsinit_line(int *myarray, const char *buffer)
{
  int  t = 0;
  int  temp;  
  int  count;
  int  tempnum;
  char secbuffer[128];
  char tempbuffer[128];
  
  sscanf(buffer, "%d %d", &tempnum, &count);
  
  if ( count > MAX_PIX_AT_SLOT)
    return -1;

  sprintf(tempbuffer, "%d %d\n", tempnum, count);
  strcpy(secbuffer, buffer + strlen(tempbuffer));

  for ( t = 0; t < count + 1; t++)
    {
      sscanf(secbuffer, "%d", &tempnum);
      myarray[t] = tempnum;

      sprintf(tempbuffer, "%d\n", tempnum);
      temp = strlen(tempbuffer);
      strcpy(tempbuffer, secbuffer);
      strcpy(secbuffer, tempbuffer + temp);
    }

  return count + 1;
}

int digit_load(int number)
{
  char        filename[64];
  GtkStyle   *style;
  GdkBitmap  *mask;

  sprintf(filename, "/usr/share/gslots/pix/digit%d.xpm", number);
  filename[strlen(filename)] = 0;

  if ( number >= 12)
    return -1;
  
  style = gtk_widget_get_style(window);
  digits[number] = gdk_pixmap_create_from_xpm(window->window,
					      &mask, &style->black,
					      filename);

  return 1;
}

int pixmap_load(const char *name, int number)
{
  char        filename[64];
  GtkStyle   *style;
  GdkBitmap  *mask;

  sprintf(filename, "/usr/share/gslots/pix/%s.xpm", name);
  filename[strlen(filename)] = 0;
  
  if ( number >= MAX_PIXMAPS)
    return -1;

  style = gtk_widget_get_style(window);
  if ( pixmaps[number])
    gdk_pixmap_unref(pixmaps[number]);
  pixmaps[number] = gdk_pixmap_create_from_xpm(window->window,
					       &mask, &style->bg[GTK_STATE_NORMAL],
					       filename);

  sprintf(filename, "/usr/share/gslots/pix/s_%s.xpm", name);
  filename[strlen(filename)] = 0;

  style = gtk_widget_get_style(window);
  if ( s_pixmaps[number] )
    gdk_pixmap_unref(s_pixmaps[number]);
  mask = NULL;
  s_pixmaps[number] = gdk_pixmap_create_from_xpm(window->window,
						 &mask, &style->bg[GTK_STATE_NORMAL],
						 filename);
  return 1;
}
