/* payoff.c - Payoff chart
 *
 * gSlots is a slotmachine
 *
 * 1999 Kristian Rietveld <kristian@wxs.nl>
 *
 * this program comes with ABSOLUTELY NO WARRANTY and is published
 * under the terms from the GPL
 *
 */

/* gSlots - a nice slotmachine for Linux/X-windows/GTK+
 * Copyright (C) 1999  Kristian Rietveld <kristian@wxs.nl>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include "gslots.h"

extern int                     numberofscores;
extern gfloat                  credits;
extern gfloat                  wager;
extern gfloat                  won;
extern GdkPixmap              *s_pixmaps[MAX_PIXMAPS];
extern GdkPixmap              *payoffentrypixmap[MAX_SCORES][3];
extern struct scoreentry       thescores[MAX_SCORES];
extern struct payoffpicentry   payoffpix[MAX_SCORES][3];

/***** globals *****/

int        payoffwindowopened = 0;
GtkWidget *payoffwindow;
GtkWidget *payoffentrylabel[MAX_SCORES];
GtkWidget *payoffentrydraw[MAX_SCORES][3];
GtkWidget *payoffentrybox[MAX_SCORES];

/*** prototypes ***/
gint payoffentry_expose(GtkWidget *, GdkEventExpose *, struct payoffpicentry *);
gint payoffentry_configre(GtkWidget *, GdkEventConfigure *, struct payoffpicentry *);

/**** the functions ****/

gint payoffentry_configure(GtkWidget *widget, GdkEventConfigure *event,
			   struct payoffpicentry *buffer)
{
  int t, tt;

  t = buffer->t;
  tt = buffer->tt;

  if (payoffentrypixmap[t][tt])
    gdk_pixmap_unref((GdkPixmap *)payoffentrypixmap[t][tt]);

  if ( t > numberofscores || tt > 3)
    return FALSE;

  payoffentrypixmap[t][tt] = (GdkPixmap *)gdk_pixmap_new(widget->window,
							 22, 27, -1);

  gdk_draw_rectangle((GdkPixmap *)payoffentrypixmap[t][tt],
		     widget->style->white_gc,
		     1,
		     0, 0,
		     22, 27);

  gdk_draw_rectangle(widget->window,
		     widget->style->white_gc,
		     1,
		     0, 0,
		     32, 27);

  gdk_draw_pixmap((GdkDrawable *)payoffentrypixmap[t][tt],
		  widget->style->white_gc,
		  s_pixmaps[thescores[t].picatslot[tt]],
		  0, 0,
		  0, 0,
		  22, 27);

  return TRUE;
}

gint payoffentry_expose(GtkWidget *widget, GdkEventExpose *event,
			struct payoffpicentry *buffer)
{
  int t, tt;

  t = buffer->t;
  tt = buffer->tt;

  if ( t > numberofscores || tt > 3)
    return TRUE;

  gdk_draw_rectangle(widget->window,
		     widget->style->fg_gc[GTK_WIDGET_STATE(widget)],
		     1,
		     event->area.x, event->area.y,
		     event->area.width, event->area.height);

  gdk_draw_pixmap(widget->window,
		  widget->style->fg_gc[GTK_WIDGET_STATE(widget)],
		  (GdkPixmap *)payoffentrypixmap[t][tt],
		  event->area.x, event->area.y,
		  event->area.x, event->area.y,
		  event->area.width, event->area.height);

  return FALSE;
}

void payoff_window_close(GtkWidget *widget, gpointer data)
{
  payoffwindowopened = 0;
  gtk_widget_destroy((GtkWidget *)data);
  
  return;
}

void display_payoffchart(GtkWidget *widget, gpointer data)
{
  int t = 0;
  int tt = 0;

  char payoffentrylabeltext[64];

  GtkWidget *payoffmainbox;
  GtkWidget *payoffmainentrybox;
  
  GtkWidget *payoffentriesbox[MAX_SCORES];
  GtkWidget *payoffpixbox[MAX_SCORES];
  GtkWidget *payofflabelbox[MAX_SCORES];
  
  GtkWidget *payoffmainlabel;
  GtkWidget *payoffseparator;
  GtkWidget *payoffbuttonbox;
  GtkWidget *payoffclosebutton;
  
  if ( payoffwindowopened )
    return;

  payoffwindow = gtk_window_new(GTK_WINDOW_TOPLEVEL);
  gtk_signal_connect(GTK_OBJECT(payoffwindow), "destroy",
		     GTK_SIGNAL_FUNC(payoff_window_close),
		     (gpointer)payoffwindow);
  gtk_signal_connect(GTK_OBJECT(payoffwindow), "delete_event",
		     GTK_SIGNAL_FUNC(payoff_window_close),
		     (gpointer)payoffwindow);
  gtk_window_set_policy(GTK_WINDOW(payoffwindow), FALSE, FALSE, FALSE);
  gtk_window_set_title(GTK_WINDOW(payoffwindow), ID " - Payoff chart");
  gtk_container_border_width(GTK_CONTAINER(payoffwindow), 3);

  payoffmainbox = gtk_vbox_new(FALSE, 0);
  gtk_container_add(GTK_CONTAINER(payoffwindow), payoffmainbox);
  gtk_widget_show(payoffmainbox);

  payoffmainlabel = gtk_label_new("score = bucks (score * wager)\n");
  gtk_box_pack_start(GTK_BOX(payoffmainbox), payoffmainlabel,
		     FALSE, FALSE, 0);
  gtk_widget_show(payoffmainlabel);

  payoffmainentrybox = gtk_vbox_new(FALSE, 0);
  gtk_box_pack_start(GTK_BOX(payoffmainbox), payoffmainentrybox,
		     FALSE, FALSE, 3);
  gtk_widget_show(payoffmainentrybox);

  for ( t = 0; t < numberofscores; t++)
    {
      payoffentriesbox[t] = gtk_hbox_new(FALSE, 5);
      gtk_box_pack_start(GTK_BOX(payoffmainentrybox), payoffentriesbox[t],
			 FALSE, FALSE, 0);
      gtk_widget_show(payoffentriesbox[t]);

      payoffpixbox[t] = gtk_hbox_new(FALSE, 5);
      gtk_box_pack_start(GTK_BOX(payoffentriesbox[t]), payoffpixbox[t],
			 FALSE, FALSE, 0);
      gtk_widget_show(payoffpixbox[t]);
      
      payofflabelbox[t] = gtk_hbox_new(FALSE, 0);
      gtk_box_pack_start(GTK_BOX(payoffentriesbox[t]), payofflabelbox[t],
			 FALSE, FALSE, 0);
      gtk_widget_show(payofflabelbox[t]);
      
      /*********************************************/

      payoffentrybox[t] = gtk_hbox_new(TRUE, 5);
      gtk_box_pack_start(GTK_BOX(payoffpixbox[t]),
			 payoffentrybox[t], FALSE, FALSE, 5);
      gtk_widget_show(payoffentrybox[t]);

      for (tt = 0; tt < 3; tt++)
	{
	  payoffpix[t][tt].t = t;
	  payoffpix[t][tt].tt = tt;

	  payoffentrydraw[t][tt] = gtk_drawing_area_new();
	  gtk_drawing_area_size(GTK_DRAWING_AREA(payoffentrydraw[t][tt]),
				32, 27);
	  gtk_signal_connect(GTK_OBJECT(payoffentrydraw[t][tt]), "configure_event",
			     GTK_SIGNAL_FUNC(payoffentry_configure),
			     &payoffpix[t][tt]);
	  gtk_signal_connect(GTK_OBJECT(payoffentrydraw[t][tt]), "expose_event",
			     GTK_SIGNAL_FUNC(payoffentry_expose),
			     &payoffpix[t][tt]);
	  gtk_widget_set_events(payoffentrydraw[t][tt],
				GDK_EXPOSURE_MASK);
	  gtk_widget_set_usize(payoffentrydraw[t][tt], 32, 27);
	  gtk_box_pack_start(GTK_BOX(payoffentrybox[t]), payoffentrydraw[t][tt],
			     FALSE, FALSE, 5);
	  gtk_widget_show(payoffentrydraw[t][tt]);
	}
      
      sprintf(payoffentrylabeltext, "Score: %5.2f (%d * %5.2f)\n",
	      thescores[t].score * wager,
	      thescores[t].score, wager);
      payoffentrylabel[t] = gtk_label_new(payoffentrylabeltext);
      gtk_widget_set_usize(payoffentrylabel[t], 0, 32);
      gtk_box_pack_start(GTK_BOX(payofflabelbox[t]), payoffentrylabel[t],
			 FALSE, FALSE, 0);
      gtk_widget_show(payoffentrylabel[t]);
    }

  payoffseparator = gtk_hseparator_new();
  gtk_box_pack_start(GTK_BOX(payoffmainbox), payoffseparator, 
		     FALSE, FALSE, 3);
  gtk_widget_show(payoffseparator);

  payoffbuttonbox = gtk_hbox_new(TRUE, 0);
  gtk_box_pack_start(GTK_BOX(payoffmainbox), payoffbuttonbox,
		     FALSE, FALSE, 3);
  gtk_widget_show(payoffbuttonbox);

  payoffclosebutton = gtk_button_new_with_label("Close");
  gtk_signal_connect(GTK_OBJECT(payoffclosebutton), "clicked",
		     GTK_SIGNAL_FUNC(payoff_window_close),
		     (gpointer)payoffwindow);
  gtk_box_pack_start(GTK_BOX(payoffbuttonbox), payoffclosebutton,
		     TRUE, TRUE, 0);
  gtk_widget_show(payoffclosebutton);

  gtk_widget_show(payoffwindow);

  payoffwindowopened = 1;

  return;
}

void payoff_window_new_wager_handle()
{
  int    t = 0;
  gchar  payoffentrylabeltext[64];
  
  for ( t = 0; t < numberofscores; t++)
    {
      sprintf((char *)payoffentrylabeltext, "Score: %5.2f (%d * %5.2f)\n",
	      thescores[t].score * wager,
	      thescores[t].score, wager);
      gtk_label_set(GTK_LABEL(payoffentrylabel[t]), 
		    (gchar *)payoffentrylabeltext);
      
    }

  gtk_widget_queue_draw(payoffwindow);
  
  return;
}
